@@ -1,8 +1,9 @@
+import json
+import urllib.parse
 from typing import Any, Dict, Optional
 
 import inquirer
 import requests
-
 from pandas import DataFrame
 
 from .exceptions import AuthError, ConfigError
@@ -45,7 +46,7 @@ class Metabasic(object):
         self.__check_config()
 
         headers = {
-            "Content-Type": "application/json",
+            "Content-Type": "application/x-www-form-urlencoded",
             "X-Metabase-Session": self.session_id,
         }
 
@@ -55,12 +56,16 @@ class Metabasic(object):
             "type": "native",
         }
 
-        resp = requests.post(f"{self.domain}/api/dataset", json=body, headers=headers)
+        data = "query=" + urllib.parse.quote(json.dumps(body))
+
+        resp = requests.post(
+            f"{self.domain}/api/dataset/json", data=data, headers=headers
+        )
 
         if resp.status_code != 202:
             raise Exception(resp)
 
-        return resp.json()["data"]
+        return resp.json()
 
     def get_dataframe(self, query: str) -> DataFrame:
         """Queries the currently selected database, returning a Pandas DataFrame.
@@ -74,7 +79,7 @@ class Metabasic(object):
 
         res = self.query(query)
 
-        df = DataFrame(res["rows"], columns=[i["name"] for i in res["cols"]])
+        df = DataFrame(res)
 
         return df
 
